@@ -8,81 +8,6 @@
 #' @keywords internal
 NULL
 
-#' @describeIn update_indention Inserts indention based on round, square and
-#'   curly brackets.
-#' @keywords internal
-indent_braces <- function(pd, indent_by) {
-  indent_indices <- compute_indent_indices(
-    pd,
-    token_opening = c("'('", "'['", "'{'"),
-    token_closing = c("')'", "']'", "'}'")
-  )
-  pd$indent[indent_indices] <- pd$indent[indent_indices] + indent_by
-  set_unindention_child(pd, token = "')'", unindent_by = indent_by)
-}
-
-#' @describeIn update_indention Indents *all* tokens after `token` - including
-#'   the last token.
-#' @keywords internal
-indent_op <- function(pd,
-                      indent_by,
-                      token = c(
-                        math_token,
-                        logical_token,
-                        special_token,
-                        "LEFT_ASSIGN",
-                        "EQ_ASSIGN",
-                        "'$'"
-                      )) {
-  indent_indices <- compute_indent_indices(pd, token)
-  pd$indent[indent_indices] <- pd$indent[indent_indices] + indent_by
-  pd
-}
-
-#' Revert the indention of function declaration header
-#'
-#' Necessary for consistent indention of the function declaration header.
-#' @param pd A parse table.
-#' @seealso set_unindention_child update_indention_ref_fun_dec
-#' @keywords internal
-unindent_fun_dec <- function(pd) {
-  if (is_function_dec(pd)) {
-    idx_closing_brace <- which(pd$token %in% "')'")
-    fun_dec_head <- seq2(2L, idx_closing_brace)
-    pd$indent[fun_dec_head] <- 0L
-  }
-  pd
-}
-
-#' @describeIn update_indention Updates indention for token EQ_SUB. Only differs
-#'   from [indent_op()] in the sense that not all subsequent tokens in the parse
-#'   table are necessarily indented, as `EQ_SUB` and `EQ_FORMALS` can occur
-#'   multiple times in a parse table.
-#'   occurs is not indented (see[compute_indent_indices()])
-#' @keywords internal
-indent_eq_sub <- function(pd,
-                          indent_by,
-                          token = c("EQ_SUB", "EQ_FORMALS")) {
-  eq_sub <- which(pd$token %in% token)
-  if (length(eq_sub) == 0) {
-    return(pd)
-  }
-  has_line_break <- which(pd$lag_newlines > 0)
-  indent_indices <- intersect(eq_sub + 1, has_line_break)
-  pd$indent[indent_indices] <- pd$indent[indent_indices] + indent_by
-  pd
-}
-
-
-#' @describeIn update_indention Is used to indent for / while / if / if-else
-#'   statements that do not have curly parenthesis.
-#' @keywords internal
-indent_without_paren <- function(pd, indent_by = 2) {
-  pd %>%
-    indent_without_paren_for_while_fun(indent_by) %>%
-    indent_without_paren_if_else(indent_by)
-}
-
 #' @describeIn update_indention Is used to indent for and statements and function
 #'   definitions without parenthesis.
 #' @keywords internal
@@ -295,8 +220,8 @@ pd_is_multi_line <- function(pd) {
 #' Update the newlines attribute
 #'
 #' As we work only with the `lag_newlines` attribute for setting the line
-#' breaks, (R/rules-line_break.R) but we need `newlines` to determine
-#' whether or not to set `spaces` (R/rules-spacing.R), we have to update the
+#' breaks (`R/rules-line_breaks.R`), but we need `newlines` to determine
+#' whether or not to set `spaces` (`R/rules-spaces.R`), we have to update the
 #' attribute. We cannot simply use `dplyr::lead(pd$lag_newlines)` since we would
 #' lose information for the last token. `spaces` is left as is in
 #' R/rules-spacing.R for tokens at the end of a line since this allows styling
@@ -306,7 +231,7 @@ pd_is_multi_line <- function(pd) {
 #' @seealso choose_indention
 #' @keywords internal
 update_newlines <- function(pd) {
-  npd <- nrow(pd) - 1
-  pd$newlines[seq_len(npd)] <- pd$lag_newlines[seq_len(npd) + 1]
+  seq_pd <- seq_len(nrow(pd) - 1)
+  pd$newlines[seq_pd] <- pd$lag_newlines[seq_pd + 1]
   pd
 }
