@@ -20,7 +20,7 @@
 #' @importFrom rlang abort
 #' @keywords internal
 test_collection <- function(test, sub_test = NULL,
-                            write_back = TRUE,
+                            dry = "off",
                             write_tree = NA,
                             transformer,
                             ...) {
@@ -41,15 +41,22 @@ test_collection <- function(test, sub_test = NULL,
 
   out_names <- construct_out(in_names)
 
-  out_items <- file.path(path, out_names)
-  in_items <- file.path(path, in_names)
-
-  out_trees <- construct_tree(in_items)
+  if (getOption("styler.test_dir_writable", TRUE)) {
+    out_items <- file.path(path, out_names)
+    in_items <- file.path(path, in_names)
+    out_trees <- construct_tree(in_items)
+  } else {
+    in_items <- file.path(path, in_names)
+    out_items <- file.path(tempdir(), out_names)
+    ref_items <- file.path(path, out_names)
+    file.copy(ref_items, out_items, overwrite = TRUE, copy.mode = FALSE)
+    out_trees <- file.path(tempdir(), construct_tree(in_names))
+  }
 
   pwalk(list(in_items, out_items, in_names, out_names, out_trees),
     transform_and_check,
     transformer = transformer,
-    write_back = write_back,
+    dry = dry,
     write_tree = write_tree,
     ...
   )
@@ -87,27 +94,29 @@ construct_tree <- function(in_paths, suffix = "_tree") {
 #' @param in_name The label of the in_item, defaults to `in_item`.
 #' @param out_name The label of the out_item, defaults to `out_item`.
 #' @param transformer A function to apply to the content of `in_item`.
-#' @param write_back Whether the results of the transformation should be written
-#'   to the output file.
 #' @param write_tree Whether or not the tree structure of the test should be
 #'   computed and written to a file. Note that this needs R >= 3.2
 #'   (see [set_arg_write_tree()]). If the argument is set to `NA`, the function
 #'   determines whether R >= 3.2 is in use and if so, trees will be written.
 #' @param ... Parameters passed to transformer function.
 #' @param out_tree Name of tree file if written out.
+#' @inheritParams transform_utf8
 #' @importFrom utils write.table
 #' @importFrom rlang warn
 #' @keywords internal
 transform_and_check <- function(in_item, out_item,
                                 in_name = in_item, out_name = out_item,
-                                transformer, write_back,
+                                transformer, dry,
                                 write_tree = NA,
                                 out_tree = "_tree", ...) {
   write_tree <- set_arg_write_tree(write_tree)
   read_in <- xfun::read_utf8(in_item)
   if (write_tree) {
     create_tree(read_in) %>%
-      write.table(out_tree, col.names = FALSE, row.names = FALSE, quote = FALSE, fileEncoding = "UTF-8")
+      write.table(out_tree,
+        col.names = FALSE, row.names = FALSE, quote = FALSE,
+        fileEncoding = "UTF-8"
+      )
   }
   transformed_text <- read_in %>%
     transformer(...) %>%
@@ -121,7 +130,7 @@ transform_and_check <- function(in_item, out_item,
   transformed <- transform_utf8(
     out_item,
     function(x) transformed_text,
-    write_back = write_back
+    dry = dry
   )
 
   if (transformed) {
@@ -152,7 +161,7 @@ NULL
 #'   transformations but remove EOL spaces and indention due to the way the
 #'   serialization is set up.
 #' @keywords internal
-style_empty <- function(text) {
+style_empty <- function(text, base_indention = 0) {
   transformers <- list(
     # transformer functions
     initialize = default_style_guide_attributes,
@@ -164,13 +173,16 @@ style_empty <- function(text) {
     reindention       = specify_reindention(),
     NULL
   )
-  transformed_text <- parse_transform_serialize_r(text, transformers)
+  transformed_text <- parse_transform_serialize_r(text,
+    transformers = transformers,
+    base_indention = base_indention
+  )
   transformed_text
 }
 
 #' @describeIn test_transformer Transformations for indention based on operators
 #' @keywords internal
-style_op <- function(text) {
+style_op <- function(text, base_indention = 0) {
   transformers <- list(
     # transformer functions
     initialize        = default_style_guide_attributes,
@@ -183,7 +195,10 @@ style_op <- function(text) {
     NULL
   )
 
-  transformed_text <- parse_transform_serialize_r(text, transformers)
+  transformed_text <- parse_transform_serialize_r(text,
+    transformers = transformers,
+    base_indention = base_indention
+  )
   transformed_text
 }
 
@@ -234,18 +249,20 @@ copy_to_tempdir <- function(path_perm = testthat_file()) {
 #'   first run.
 #' @keywords internal
 n_times_faster_with_cache <- function(x1, x2 = x1, ...,
-                                fun = styler::style_text,
-                                n = 3,
-                                clear = "always") {
+                                      fun = styler::style_text,
+                                      n = 3,
+                                      clear = "always") {
   rlang::arg_match(clear, c("always", "final", "never", "all but last"))
-  capture.output(
-    out <- purrr::map(1:n, n_times_faster_bench,
-      x1 = x1, x2 = x2, fun = fun,
-      ..., n = n, clear = clear) %>%
+
+  out <- purrr::map(1:n, n_times_faster_bench,
+    x1 = x1, x2 = x2, fun = fun,
+    ..., n = n, clear = clear
+  ) %>%
     purrr::map_dbl(
-      ~ unname(.x$first["elapsed"] / .x$second["elapsed"])) %>%
+      ~ unname(.x$first["elapsed"] / .x$second["elapsed"])
+    ) %>%
     mean()
-  )
+
   if (clear %in% c("always", "final")) {
     clear_testthat_cache()
   }
@@ -267,7 +284,7 @@ n_times_faster_bench <- function(i, x1, x2, fun, ..., n, clear) {
   }
   list(
     first = first,
-    second =  second
+    second = second
   )
 }
 
@@ -321,3 +338,31 @@ fresh_testthat_cache <- function() {
   activate_testthat_cache()
 }
 
+cache_more_specs_default <- function() {
+  cache_more_specs(include_roxygen_examples = TRUE, base_indention = 0)
+}
+
+#' Test `transformers_drop` for consistency
+#'
+#' Check if the argument `transformers_drop` in [create_style_guide()] is
+#' consistent with the transformers specified in that function.
+#' @param transformers The output of [create_style_guide()] we want to test.
+#' @keywords internal
+test_transformers_drop <- function(transformers) {
+  scopes <- intersect(
+    names(transformers$transformers_drop),
+    names(transformers)
+  )
+
+  purrr::walk2(transformers$transformers_drop, transformers[scopes], function(x, y) {
+    # all x must be in y. select the x that are not in y
+    diff <- setdiff(names(x), names(y))
+    if (length(diff) > 0) {
+      rlang::abort(paste(
+        "transformers_drop specifies exclusion rules for transformers that ",
+        "are not in the style guilde. Please add the rule to the style guide ",
+        "or remove the dropping rules:", paste(diff, collapse = ", ")
+      ))
+    }
+  })
+}
