@@ -5,20 +5,22 @@
 #' @param files A character vector with paths to the file that should be
 #'   transformed.
 #' @inheritParams make_transformer
+#' @inheritParams transform_file
 #' @section Value:
 #' Invisibly returns a data frame that indicates for each file considered for
-#' styling whether or not it was actually changed.
+#' styling whether or not it was actually changed (or would be changed when
+#' `dry` is not "off").
 #' @keywords internal
-transform_files <- function(files, transformers, include_roxygen_examples) {
-  transformer <- make_transformer(transformers, include_roxygen_examples)
+transform_files <- function(files, transformers, include_roxygen_examples, base_indention, dry) {
+  transformer <- make_transformer(transformers, include_roxygen_examples, base_indention)
   max_char <- min(max(nchar(files), 0), getOption("width"))
   len_files <- length(files)
-  if (len_files > 0L) {
+  if (len_files > 0L && !getOption("styler.quiet", FALSE)) {
     cat("Styling ", len_files, " files:\n")
   }
 
   changed <- map_lgl(files, transform_file,
-    fun = transformer, max_char_path = max_char
+    fun = transformer, max_char_path = max_char, dry = dry
   )
   communicate_summary(changed, max_char)
   communicate_warning(changed, transformers)
@@ -34,7 +36,7 @@ transform_files <- function(files, transformers, include_roxygen_examples) {
 #' @param message_after The message to print after the path.
 #' @param message_after_if_changed The message to print after `message_after` if
 #'   any file was transformed.
-#' @inheritParams transform_utf8
+#' @inheritParams transform_code
 #' @param ... Further arguments passed to [transform_utf8()].
 #' @keywords internal
 transform_file <- function(path,
@@ -43,21 +45,26 @@ transform_file <- function(path,
                            message_before = "",
                            message_after = " [DONE]",
                            message_after_if_changed = " *",
-                           ...) {
+                           ...,
+                           dry) {
   char_after_path <- nchar(message_before) + nchar(path) + 1
   max_char_after_message_path <- nchar(message_before) + max_char_path + 1
   n_spaces_before_message_after <-
     max_char_after_message_path - char_after_path
-  cat(
-    message_before, path,
-    rep_char(" ", max(0L, n_spaces_before_message_after)),
-    append = FALSE
-  )
-  changed <- transform_code(path, fun = fun, ...)
+  if (!getOption("styler.quiet", FALSE)) {
+    cat(
+      message_before, path,
+      rep_char(" ", max(0L, n_spaces_before_message_after)),
+      append = FALSE
+    )
+  }
+  changed <- transform_code(path, fun = fun, ..., dry = dry)
 
   bullet <- ifelse(is.na(changed), "warning", ifelse(changed, "info", "tick"))
 
-  cli::cat_bullet(bullet = bullet)
+  if (!getOption("styler.quiet", FALSE)) {
+    cli::cat_bullet(bullet = bullet)
+  }
   invisible(changed)
 }
 
@@ -75,29 +82,45 @@ transform_file <- function(path,
 #' @importFrom purrr when
 make_transformer <- function(transformers,
                              include_roxygen_examples,
+                             base_indention,
                              warn_empty = TRUE) {
   force(transformers)
   assert_transformers(transformers)
 
   function(text) {
+    text <- trimws(text, which = "right")
     should_use_cache <- cache_is_activated()
 
     if (should_use_cache) {
-      use_cache <- is_cached(text, transformers)
+      use_cache <- is_cached(
+        text, transformers,
+        cache_more_specs(
+          include_roxygen_examples = include_roxygen_examples,
+          base_indention = base_indention
+        )
+      )
     } else {
       use_cache <- FALSE
     }
 
     if (!use_cache) {
       transformed_code <- text %>%
-        parse_transform_serialize_r(transformers, warn_empty = warn_empty) %>%
+        parse_transform_serialize_r(transformers,
+          base_indention = base_indention,
+          warn_empty = warn_empty
+        ) %>%
         when(
           include_roxygen_examples ~
-          parse_transform_serialize_roxygen(., transformers),
+          parse_transform_serialize_roxygen(.,
+            transformers = transformers, base_indention = base_indention
+          ),
           ~.
         )
       if (should_use_cache) {
-        cache_write(transformed_code, transformers)
+        cache_write(
+          transformed_code, transformers,
+          cache_more_specs(include_roxygen_examples, base_indention)
+        )
       }
       transformed_code
     } else {
@@ -132,19 +155,28 @@ make_transformer <- function(transformers,
 #' [parse_transform_serialize_r()].
 #' @importFrom purrr map_at flatten_chr
 #' @keywords internal
-parse_transform_serialize_roxygen <- function(text, transformers) {
+parse_transform_serialize_roxygen <- function(text, transformers, base_indention) {
   roxygen_seqs <- identify_start_to_stop_of_roxygen_examples_from_text(text)
   if (length(roxygen_seqs) < 1L) {
     return(text)
   }
+  if (!rlang::is_installed("roxygen2")) {
+    rlang::abort(paste0(
+      "To style roxygen code examples, you need to have the package ",
+      "`{roxygen2}` installed. To exclude them from styling, set ",
+      "`include_roxygen_examples = FALSE`."
+    ))
+  }
   split_segments <- split_roxygen_segments(text, unlist(roxygen_seqs))
   map_at(split_segments$separated, split_segments$selectors,
     style_roxygen_code_example,
-    transformers = transformers
+    transformers = transformers,
+    base_indention = base_indention
   ) %>%
     flatten_chr()
 }
 
+
 #' Split text into roxygen and non-roxygen example segments
 #'
 #' @param text Roxygen comments
@@ -162,7 +194,7 @@ parse_transform_serialize_roxygen <- function(text, transformers) {
 #' @keywords internal
 split_roxygen_segments <- function(text, roxygen_examples) {
   if (is.null(roxygen_examples)) {
-    return(lst(separated = list(text), selectors = NULL))
+    return(list(separated = list(text), selectors = NULL))
   }
   all_lines <- seq2(1L, length(text))
   active_segment <- as.integer(all_lines %in% roxygen_examples)
@@ -170,7 +202,7 @@ split_roxygen_segments <- function(text, roxygen_examples) {
   separated <- split(text, factor(segment_id))
   restyle_selector <- ifelse(roxygen_examples[1] == 1L, odd_index, even_index)
 
-  lst(separated, selectors = restyle_selector(separated))
+  list(separated = separated, selectors = restyle_selector(separated))
 }
 
 #' Parse, transform and serialize text
@@ -179,30 +211,38 @@ split_roxygen_segments <- function(text, roxygen_examples) {
 #' @param warn_empty Whether or not a warning should be displayed when `text`
 #'   does not contain any tokens.
 #' @inheritParams compute_parse_data_nested
-#' @inheritParams apply_transformers
+#' @inheritParams parse_transform_serialize_r_block
 #' @seealso [parse_transform_serialize_roxygen()]
 #' @importFrom rlang abort
 #' @keywords internal
 parse_transform_serialize_r <- function(text,
                                         transformers,
+                                        base_indention,
                                         warn_empty = TRUE) {
-  text <- assert_text(text)
-  pd_nested <- compute_parse_data_nested(text, transformers)
+  more_specs <- cache_more_specs(
+    include_roxygen_examples = TRUE, base_indention = base_indention
+  )
 
-  blank_lines_to_next_expr <- find_blank_lines_to_next_block(pd_nested)
+  text <- assert_text(text)
+  pd_nested <- compute_parse_data_nested(text, transformers, more_specs)
   if (nrow(pd_nested) == 0) {
     if (warn_empty) {
       warn("Text to style did not contain any tokens. Returning empty string.")
     }
     return("")
   }
+  transformers <- transformers_drop(
+    if (getRversion() < 3.4) text else pd_nested$text[!pd_nested$is_cached],
+    transformers
+  )
 
   text_out <- pd_nested %>%
     split(pd_nested$block) %>%
     unname() %>%
-    map2(blank_lines_to_next_expr,
+    map2(find_blank_lines_to_next_block(pd_nested),
       parse_transform_serialize_r_block,
-      transformers = transformers
+      transformers = transformers,
+      base_indention = base_indention
     ) %>%
     unlist()
 
@@ -211,11 +251,43 @@ parse_transform_serialize_r <- function(text,
   }
   text_out <- convert_newlines_to_linebreaks(text_out)
   if (cache_is_activated()) {
-    cache_by_expression(text_out, transformers)
+    cache_by_expression(text_out, transformers, more_specs = more_specs)
   }
   text_out
 }
 
+
+#' Remove transformers that are not needed
+#'
+#' The goal is to speed up styling by removing all rules that are only
+#' applicable in contexts that don't occur often, e.g. for most code, we don't
+#' expect ";" to be in it, so we don't need to apply `resolve_semicolon()` on
+#' every *nest*.
+#' @param text Text to parse. Can also be the column `text` of the output of
+#'   [compute_parse_data_nested()], where each element is a token (instead of a
+#'   line).
+#' @param transformers the transformers.
+#' @keywords internal
+#' @seealso specify_transformers_drop
+transformers_drop <- function(text, transformers) {
+  is_colon <- text == ";"
+  if (any(is_colon)) {
+    # ; can only be parsed when on the same line as other token, not the case
+    # here since text is output of compute_parse_data_nested.
+    text <- c(text[!is_colon], "1;")
+  }
+  token <- unique(tokenize(text)$token)
+  for (scope in c("line_break", "space", "token", "indention")) {
+    rules <- transformers$transformers_drop[[scope]]
+    for (rule in names(rules)) {
+      if (!any(rules[[rule]] %in% token)) {
+        transformers[[scope]][rule] <- NULL
+      }
+    }
+  }
+  transformers
+}
+
 #' Apply transformers to a parse table
 #'
 #' The column `multi_line` is updated (after the line break information is
@@ -242,7 +314,10 @@ parse_transform_serialize_r <- function(text,
 apply_transformers <- function(pd_nested, transformers) {
   transformed_updated_multi_line <- post_visit(
     pd_nested,
-    c(transformers$initialize, transformers$line_break, set_multi_line, update_newlines)
+    c(
+      transformers$initialize, transformers$line_break, set_multi_line,
+      if (length(transformers$line_break) != 0) update_newlines
+    )
   )
 
   transformed_all <- pre_visit(
@@ -271,15 +346,16 @@ apply_transformers <- function(pd_nested, transformers) {
 #'   Needed for reverse engineering the scope.
 #' @keywords internal
 can_verify_roundtrip <- function(transformers) {
-  is.null(transformers$token)
+  length(transformers$token) == 0
 }
 
 #' Verify the styling
 #'
 #' If scope was set to "line_breaks" or lower (compare [tidyverse_style()]),
 #' we can compare the expression before and after styling and return an error if
-#' it is not the same. Note that this method ignores comments and no
-#' verification can be conducted if scope > "line_breaks".
+#' it is not the same. Note that this method ignores roxygen code examples and
+#' comments and no verification can be conducted if tokens are in the styling
+#' scope.
 #' @inheritParams expressions_are_identical
 #' @importFrom rlang abort
 #' @examples
