@@ -5,56 +5,68 @@ knitr::knit_engines$set(list(
     options$comment <- ""
     knitr::engine_output(
       options,
-      
       c("# Before", options$code),
       c("# After", styler::style_text(options$code))
     )
   }
 ))
 
+## -----------------------------------------------------------------------------
+library(styler)
+style_text("a + b", transformers = tidyverse_style(scope = "indention"))
+
+## ---- results = 'hide'--------------------------------------------------------
+# equivalent
+style_text("a + b", transformers = tidyverse_style(scope = "indention"))
+style_text("a + b", scope = "indention")
 
 ## -----------------------------------------------------------------------------
-library("styler")
-library("magrittr")
-style_text("a=3; 2", scope = "spaces")
+# tokens and everything less invasive
+style_text("a=2", scope = "tokens")
 
-## -----------------------------------------------------------------------------
-style_text("a=3; 2", scope = "tokens")
-
-## -----------------------------------------------------------------------------
-style_text("if(x) {66 } else {a=3}", scope = "line_breaks")
-
-## -----------------------------------------------------------------------------
-code <- c(
-    "a <- function() { ", 
-    "                a=3", 
-    "}"
-)
-
-style_text(code, scope = "spaces")
-
-## -----------------------------------------------------------------------------
-style_text(code, scope = "indention")
+# just tokens and indention
+style_text("a=2", scope = I(c("tokens", "indention")))
 
 ## -----------------------------------------------------------------------------
 style_text(
-  "data_frame(
+  "tibble::tibble(
      small  = 2 ,
      medium = 4,#comment without space
      large  = 6
-   )", strict = FALSE
+   )"
 )
 
 ## -----------------------------------------------------------------------------
-style_text(
-  "a <-   'one'   #just one
-   abc <- 'three' # three", 
-  strict = FALSE
+styler::style_text(
+  "
+  #> blocks
+  blibala= 3
+  # styler: off
+  I_have(good+reasons, to = turn_off,
+    styler
+  )
+  # styler: on
+  1+1
+
+  #> inline
+  ignore( this) # styler: off
+  f( ) # not ignored anymore
+"
 )
 
+## -----------------------------------------------------------------------------
+out <- withr::with_tempfile(
+  "code.R",
+  {
+    writeLines("1+1", "code.R")
+    style_file("code.R", dry = "on")
+  }
+)
+out
+
 ## -----------------------------------------------------------------------------
 style_text(
-  "1++1/2*2^2", 
+  "1++1/2*2^2",
   math_token_spacing = specify_math_token_spacing(zero = c("'/'", "'*'", "'^'"))
 )
 
@@ -67,7 +79,7 @@ style_text(
     "33",
     "}"
   ),
-  reindention = specify_reindention(regex_pattern = "###", indention = 0)
-  
+  reindention = specify_reindention(regex_pattern = "###", indention = 0),
+  indent_by = 4
 )
 
