@@ -34,5 +34,18 @@ x <- '	2' # there is a tab emebbed (created with writeLines("x <- '\t2'"))
 x <- '\001'
 '\x01'
 
-# FIXME: "\01" gives an error when not in a comment
-# FIXME: this too: '\01'
+"\01"
+'\01'
+
+#' things
+#'
+#' @examplesIf N
+#' call("\n")
+#' ano("\\.", further = X)
+NULL
+
+#' things
+#'
+#' @examplesIf call("\n")
+#' ano("\\.", further = X)
+NULL
