@@ -3,8 +3,7 @@ context("indention operators")
 test_that("pipe is indended correctly", {
   expect_warning(test_collection("indention_operators",
     "pipe",
-    transformer = style_text,
-    write_back = TRUE
+    transformer = style_text
   ), NA)
 })
 
