@@ -11,6 +11,19 @@ test_that("line breaks work in general", {
   ), NA)
 })
 
+test_that("blank lines in function calls are removed for strict = TRUE", {
+  expect_warning(test_collection("line_breaks_fun_call",
+    "blank-strict",
+    transformer = style_text
+  ), NA)
+
+  expect_warning(test_collection("line_breaks_fun_call",
+    "blank-non-strict",
+    transformer = style_text, strict = FALSE
+  ), NA)
+})
+
+
 test_that("line breaks are not applied with non-strict", {
   expect_warning(test_collection("line_breaks_fun_call",
     "token_dependent_complex_non_strict",
